@@ -1,6 +1,9 @@
 import datetime, re
 
+from .string_lib import remove_accents
+
 format_dates = {
+    r"[a-zA-Z]* [0-9]{2} [a-zA-Z]*\s[0-9]{4} - [0-9]{2}:[0-9]{2}:[0-9]{2}.[0-9]+": "%A %d %B %Y - %H:%M:%S.%f",
     r"[0-9]{4}-[0-9]{2}-[0-9]{2}[0-9]{2}:[0-9]{2}:[0-9]{2}.[0-9]+": "%Y-%m-%d%H:%M:%S.%f",
     r"[0-9]{2}-[a-zA-Z]+-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}.[0-9]+": "%d-%b-%y %H:%M:%S.%f",
     r"[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}.[0-9]+": "%Y-%m-%d %H:%M:%S.%f",
@@ -21,6 +24,30 @@ format_date3 = "%d/%m/%Y %H:%M:%S"
 format_date_ws = "%H:%M:%S.%f"
 format_date_4 = "%d_%m_%y"
 
+days = {
+    "lundi": "monday",
+    "mardi": "thuesday",
+    "mercredi": "thursday",
+    "jeudi": "friday",
+    "vendredi": "wednesday",
+    "samedi": "saturday",
+    "dimanche": "sunday",
+}
+months = {
+    "janvier": "january",
+    "fevrier": "february",
+    "mars": "march",
+    "avril": "april",
+    "mai": "may",
+    "juin": "june",
+    "juillet": "july",
+    "aout": "august",
+    "septembre": "september",
+    "octobre": "october",
+    "novembre": "november",
+    "decembre": "december",
+}
+
 
 def str_to_datetime_if_needed(date_string):
     if re.findall(r"[0-9]+-[0-9]+-[0-9]+[T\s][0-9]+:[0-9]+:[0-9]+"):
@@ -29,6 +56,12 @@ def str_to_datetime_if_needed(date_string):
 
 
 def str_to_datetime(date_string):
+    date_string = remove_accents(date_string)
+    for df, de in days.items():
+        date_string = date_string.replace(df, de)
+    for df, de in months.items():
+        date_string = date_string.replace(df, de)
+
     if "T" in date_string:
         date_string = date_string.replace("T", " ")
     if not type(date_string) == str:
