@@ -1,5 +1,5 @@
-import dataclasses
-import enum, inspect, operator, re
+import dataclasses, traceback
+import enum, inspect, operator, re, copy
 from dataclasses import dataclass, field, is_dataclass, _MISSING_TYPE
 from collections import OrderedDict
 
@@ -148,6 +148,9 @@ class AlphaClass:
                     setattr(self, mapping_attribute.name, value)
                     mapped.append(mapping_attribute.name)
 
+    def copy(self):
+        return copy.copy(self)
+
 
 DATACLASS_AUTO_MAP_MATCHS = {}
 
